Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1654)

Unified Diff: chrome/browser/chromeos/login/screens/app_launch_splash_screen_actor.h

Issue 79113002: kiosk: Network connectivity test during launch. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase, add policy and only show network error screen once Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/screens/app_launch_splash_screen_actor.h
diff --git a/chrome/browser/chromeos/login/screens/app_launch_splash_screen_actor.h b/chrome/browser/chromeos/login/screens/app_launch_splash_screen_actor.h
index 83ad87844e78e3f926331dd3c6b301b7fb8795a1..2547466cd483680b86e1e4d70705e476d326c5a7 100644
--- a/chrome/browser/chromeos/login/screens/app_launch_splash_screen_actor.h
+++ b/chrome/browser/chromeos/login/screens/app_launch_splash_screen_actor.h
@@ -23,9 +23,16 @@ class AppLaunchSplashScreenActor {
class Delegate {
public:
+ // Invoked when the configure network control is clicked.
virtual void OnConfigureNetwork() = 0;
+
+ // Invoked when the app launch bailout shortcut key is pressed.
virtual void OnCancelAppLaunch() = 0;
+ // Invoked when network state is changed. |online| is true if the device
+ // is connected to the Internet.
+ virtual void OnNetworkStateChanged(bool online) = 0;
+
protected:
virtual ~Delegate() {}
};
@@ -47,8 +54,11 @@ class AppLaunchSplashScreenActor {
// Set the current app launch state.
virtual void UpdateAppLaunchState(AppLaunchState state) = 0;
// Sets whether continue control is enabled.
virtual void ToggleNetworkConfig(bool visible) = 0;
+
+ // Shows the network error and configure UI.
+ virtual void ShowNetworkConfigureUI() = 0;
};
} // namespace chromeos
@@ -47,8 +54,11 @@ class AppLaunchSplashScreenActor {
// Set the current app launch state.
virtual void UpdateAppLaunchState(AppLaunchState state) = 0;
- // Sets whether continue control is enabled.
+ // Sets whether configure network control is visible.
virtual void ToggleNetworkConfig(bool visible) = 0;

Powered by Google App Engine
This is Rietveld 408576698